Description
===========
The little home on the internet for our adaptive grid sampled Bayesian inference code. Check it out if you want to compute probability distributions over ~1-10 input parameters to a relatively computationally expensive (10's of core-seconds per evaluation) model.

More detailed documentation `here <https://pv-lab.github.io/bayesim/_build/html/index.html>`_.


Installation and Usage
======================
Install using

.. code-block:: shell

  pip install bayesim


Information
===========
:Authors:
    Rachel C. Kurchin and Giuseppe Romano

:Version: 0.10.0 as of August 2023
